#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the LeedsSportsPose dataset."""

from tensorbay.opendataset.LeedsSportsPose.loader import LeedsSportsPose

__all__ = ["LeedsSportsPose"]
